/* CSD: Cornerstone disassembler

    Copyright (C) 2014  John Elliott <jce@seasip.demon.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

package info.seasip.csd;

import java.io.*;

/** Represents per-module globals for a particular module.
 *
 * @author      John Elliott <jce@seasip.demon.co.uk>
 * @version     1.0
 * @since       2014-04-12
 */
public class ModuleGlobals extends WordChunk
{
	/** The number of module-specific globals defined by this header. */
	private int count;
	/** The offset of this particular record in the .MME file. */
	private long base;	
	/** The number of this module, 0-based. */
	private int module;

	/** Standard constructor.
	 * @param rf The .MME file.
	 * @param n  The number of globals defined.
	 * @param m  The module ID, 0-based.
	 */
	ModuleGlobals(RandomAccessFile rf, int n, int m)
	{
		super(rf);
		count = n;
		module = m;
	}

	/** Load the module globals.
	 * @throws IOException on read error. */
	public void load() throws IOException
	{
		base = file.getFilePointer();
		read(count);
	}


	/** Dump the contents of the globals index for this module.
	 * @param stream The stream to output to.
	 */
	public void showContents(PrintStream stream)
	{
		long pos;

		stream.println(";---------------------------------------");
		stream.printf ("; Module %d globals index:\n", module + 1);
		stream.println(";---------------------------------------");
		for (int n = 0; n < count; n++)
		{
			stream.printf ("; %04x: M%d Global %d = 0x%04x\n", 
				base + 2 * n, module + 1,
				n,
				words[n]);	

		}
	}
}

