/* CSD: Cornerstone disassembler

    Copyright (C) 2014  John Elliott <jce@seasip.demon.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

package info.seasip.csd;

import java.io.*;

public class ModuleIndex extends WordChunk
{
	private int moduleCount;
	private long base;

	ModuleIndex(RandomAccessFile rf)
	{
		super(rf);
	}

	public void load() throws IOException
	{
		base = file.getFilePointer();
		moduleCount = read();
		read(moduleCount);
	}

	public int getModuleCount() 
	{ 
		return moduleCount;
	}


	public int getModuleAddress(int module)
	{
		return words[module] * 256;	
	}


	public void showContents(PrintStream stream)
	{
		stream.println(";---------------------------------------");
		stream.println("; Module index:");
		stream.println(";---------------------------------------");
		stream.printf ("; %04x: Module count = %d\n", base, 
					moduleCount);
		for (int n = 0; n < moduleCount; n++)
		{
			stream.printf ("; %04x: Module %d is at %06x\n", 
				base + 2 + 2 * n, 
				n + 1, getModuleAddress(n));	

		}

	}

}

