/* CSD: Cornerstone disassembler

    Copyright (C) 2014  John Elliott <jce@seasip.demon.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

package info.seasip.csd;


/** Represents a value on the Cornerstone processor stack. Stored in two
 *  parts: an integer value, and a string annotation.
 *
 * @author      John Elliott <jce@seasip.demon.co.uk>
 * @version     1.0
 * @since       2014-04-12
 */
class StackElement
{
	/** The type of the element. A short, human-readable string. */
	public String type;
	/** The value of this element. 0-65535 for a known value, -1 for 
	 * unknown.*/
	public int value;

	/** Construct an element of generic integer type. 
	 * 
	 * @param v The numeric value. If it is less than zero, type becomes
	 * 		'unknown', else 'int'.
	 */
	StackElement(int v) 
	{
		value = v;
		if (v < 0) 
		{
			type = "unknown";
		}
		else
		{
			type = "int";
		}
	}

	/** Construct an element with a specified type.
	 * 
	 * @param v The numeric value. 
	 * @param t Its type: A short, human-readable string.
	 */
	StackElement(int v, String t) 
	{
		value = v;
		type = t;
	}
}

