/* CSD: Cornerstone disassembler

    Copyright (C) 2014  John Elliott <jce@seasip.demon.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

package info.seasip.csd;
import java.io.*;
import java.util.Vector;

/** Represents a symbol: a mapping from an address to a string.
 *
 * @author      John Elliott <jce@seasip.demon.co.uk>
 * @version     1.0
 * @since       2014-04-12
 */
public class Symbol
{
	/** The display string associated with this symbol. */
	String name;
	/** The module in which this symbol is located, 1-based. 0 may be used
	 * in future for addresses in RAM. */
	int module;
	/** The offset within the module. */
	int offset;
	/** The type of this symbol.
	 * <dl>
	 * <dt>L</dt><dd>Local jump, analysed.</dd>
	 * <dt>l</dt><dd>Local jump, not yet analysed.</dd>
	 * <dt>N</dt><dd>Annotation: CALLs to this address do not return.</dd>
	 * <dt>P</dt><dd>Procedure, analysed.</dd>
	 * <dt>p</dt><dd>Procedure, not yet analysed.</dd>
	 * </dl> */
	char type;
	/** Maximum address used by procedure. Only applies if type is P or p.
	 */
	int max;

	public Symbol()
	{
		type = ' ';
		name = null;
		offset = -1;
		module = -1;
		max = -1;
	}

	public Symbol(char t, String n, int m, int o)
	{
		type = t;
		name = n;
		module = m;
		offset = o;	
		max = -1;
	}

	public Symbol(char t, String n, int m)
	{
		type = t;
		name = n;
		module = m;
		offset = -1;	
		max = -1;
	}

	public static Integer getKey(int module, int offset)
	{
		return ((offset << 16) | (module & 0xFFFF));
	}


	public Integer getKey()
	{
		return getKey(module, offset);
	}


	public String toString()
	{
		return String.format("type=%c module=%02d offset=%04x max=%04x '%s'",	type, module, offset, max, name);
	}
}
